==> ogre-docs-1.11.2-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/class_ogre_1_1_composition_pass.js <==
var class_ogre_1_1_composition_pass =
[
    [ "InputTex", "struct_ogre_1_1_composition_pass_1_1_input_tex.html", "struct_ogre_1_1_composition_pass_1_1_input_tex" ],
    [ "PassType", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aa", [
      [ "PT_CLEAR", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaaa7d4ed28ab9cdd43e85a715bd4e068fc", null ],
      [ "PT_STENCIL", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaa43301dad285fba17915d7867665597ab", null ],
      [ "PT_RENDERSCENE", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaac8aa60611671e1b8867c1a30775ba84c", null ],
      [ "PT_RENDERQUAD", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaa39b1d2658f5c73b04755e428316ea366", null ],
      [ "PT_RENDERCUSTOM", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaaba93db3e2878858fe2fd199354c82af9", null ]
    ] ],
    [ "CompositionPass", "class_ogre_1_1_composition_pass.html#a5b5540cb8dc10175dc30c3947032013c", null ],
    [ "~CompositionPass", "class_ogre_1_1_composition_pass.html#ab8fc137845790b360d57056621cd1061", null ],
    [ "setType", "class_ogre_1_1_composition_pass.html#a8b0e3dcfccbdcc9672a96ae6dc2c0123", null ],
    [ "getType", "class_ogre_1_1_composition_pass.html#a6a51eff0938089a5fc26c1bec5c3778f", null ],
    [ "setIdentifier", "class_ogre_1_1_composition_pass.html#a56bb1d899a43195712944398e2d1bc65", null ],
    [ "getIdentifier", "class_ogre_1_1_composition_pass.html#ab60bfaaed2a48057ac8e8e7ead113f60", null ],
    [ "setMaterial", "class_ogre_1_1_composition_pass.html#a21721f49c3b10e36560adff1e563740f", null ],
    [ "setMaterialName", "class_ogre_1_1_composition_pass.html#a453231b980fc04dd9af9f330feec5236", null ],
    [ "getMaterial", "class_ogre_1_1_composition_pass.html#a0367e89580ffd67000ce52676866fa43", null ],
    [ "setFirstRenderQueue", "class_ogre_1_1_composition_pass.html#a4af9e5a958c5ec3a69f8bd797d4c2563", null ],
    [ "getFirstRenderQueue", "class_ogre_1_1_composition_pass.html#ab7f667605829412a22d0cccd9c1d7e6c", null ],
    [ "setLastRenderQueue", "class_ogre_1_1_composition_pass.html#a193d54ee08e19d538576ca300c30c006", null ],
    [ "getLastRenderQueue", "class_ogre_1_1_composition_pass.html#a1947a2e49e4c78d3fa806933690e6522", null ],
    [ "setMaterialScheme", "class_ogre_1_1_composition_pass.html#afdc03ddab7dba7ca065345a0ab5351fd", null ],
    [ "getMaterialScheme", "class_ogre_1_1_composition_pass.html#a822bb35bad3ba41e1370c08891428053", null ],
    [ "setClearBuffers", "class_ogre_1_1_composition_pass.html#a92187a460af36b8ebe0828cf6d81c277", null ],
    [ "getClearBuffers", "class_ogre_1_1_composition_pass.html#a86b647f3dff3e2fc021302c23827b603", null ],
    [ "setClearColour", "class_ogre_1_1_composition_pass.html#a749020e95d4cd6d908983d042b86e429", null ],
    [ "getClearColour", "class_ogre_1_1_composition_pass.html#a548f5811f1b762b2a64257367f564378", null ],
    [ "setAutomaticColour", "class_ogre_1_1_composition_pass.html#ad72002d4220edc51b6ac40bbd811cbee", null ],
    [ "getAutomaticColour", "class_ogre_1_1_composition_pass.html#ac4fae76a4f67e1ea70dc270be9b0daed", null ],
    [ "setClearDepth", "class_ogre_1_1_composition_pass.html#a1f0e9945281c6551ab0f21a129270339", null ],
    [ "getClearDepth", "class_ogre_1_1_composition_pass.html#a3c873101dd6bb94c9cea93fcc2a6e55b", null ],
    [ "setClearStencil", "class_ogre_1_1_composition_pass.html#ad75218db6dbe9993b5486c9c916efc0c", null ],
    [ "getClearStencil", "class_ogre_1_1_composition_pass.html#adfa90e05d769083fe4823a6fff4177c0", null ],
    [ "setStencilCheck", "class_ogre_1_1_composition_pass.html#af0f6a55176e7c69fda820a5d22a50104", null ],
    [ "getStencilCheck", "class_ogre_1_1_composition_pass.html#a31e5b47326f6357b7172faca282cb3ea", null ],
    [ "setStencilFunc", "class_ogre_1_1_composition_pass.html#a7d60b3d8f6e47891d8e5373bea31d5bd", null ],
    [ "getStencilFunc", "class_ogre_1_1_composition_pass.html#a14fcb5fbfd45871dca725c88de5a83a5", null ],
    [ "setStencilRefValue", "class_ogre_1_1_composition_pass.html#a1b8cc0c3221bfbc751328cda98c8aff7", null ],
    [ "getStencilRefValue", "class_ogre_1_1_composition_pass.html#a2fd6b67d996e8a9c9a7b8443490e997e", null ],
    [ "setStencilMask", "class_ogre_1_1_composition_pass.html#a052e16876215e11e03bcba8657faf917", null ],
    [ "getStencilMask", "class_ogre_1_1_composition_pass.html#af347ecd30bdb07219cb1794599b30ec7", null ],
    [ "setStencilFailOp", "class_ogre_1_1_composition_pass.html#ad7afd96369d5093b5eb2123f2befed58", null ],
    [ "getStencilFailOp", "class_ogre_1_1_composition_pass.html#a354620f0bec90c923b57707019195483", null ],
    [ "setStencilDepthFailOp", "class_ogre_1_1_composition_pass.html#ae3c196d705b7bf120e0d888b4867dda4", null ],
    [ "getStencilDepthFailOp", "class_ogre_1_1_composition_pass.html#adcd852af123434d7ff154a2569121d27", null ],
    [ "setStencilPassOp", "class_ogre_1_1_composition_pass.html#aff4417885952905fc8230cef47a36756", null ],
    [ "getStencilPassOp", "class_ogre_1_1_composition_pass.html#a6e14a28e603b902ee0794f78912f329f", null ],
    [ "setStencilTwoSidedOperation", "class_ogre_1_1_composition_pass.html#afa3d6c2f5f8e6ba85b7844d2bf433a5f", null ],
    [ "getStencilTwoSidedOperation", "class_ogre_1_1_composition_pass.html#a45657514c52a86f22d9d575fa248de0a", null ],
    [ "setStencilReadBackAsTextureOperation", "class_ogre_1_1_composition_pass.html#a4eb731c1f04905fee30f0317815963f6", null ],
    [ "getStencilReadBackAsTextureOperation", "class_ogre_1_1_composition_pass.html#ad3b550fd01154eddeaf8cbc7459c75f9", null ],
    [ "setInput", "class_ogre_1_1_composition_pass.html#afa546e1e7d46879c3dc6ce5dff470d4d", null ],
    [ "getInput", "class_ogre_1_1_composition_pass.html#ae5884df0782f751715d36c0027912760", null ],
    [ "getNumInputs", "class_ogre_1_1_composition_pass.html#a88aed71c3c005bea6be70c8d58db3232", null ],
    [ "clearAllInputs", "class_ogre_1_1_composition_pass.html#a05cbca68fbc408dbf755612cfb72707d", null ],
    [ "getParent", "class_ogre_1_1_composition_pass.html#a5815c0e9e598fe58d2c7f76be9167976", null ],
    [ "_isSupported", "class_ogre_1_1_composition_pass.html#ac0daef1d307ace963959896a3db64d75", null ],
    [ "setQuadCorners", "class_ogre_1_1_composition_pass.html#a186b5a3bcb90a3ce1d66f97424cd339c", null ],
    [ "getQuadCorners", "class_ogre_1_1_composition_pass.html#a0a8e642c52e2b7db79765f93b1cf5730", null ],
    [ "setQuadFarCorners", "class_ogre_1_1_composition_pass.html#ac2831cd42c94887f6e239d1460dc6b5c", null ],
    [ "getQuadFarCorners", "class_ogre_1_1_composition_pass.html#ae350fcee79e006e23d6de413253568e5", null ],
    [ "getQuadFarCornersViewSpace", "class_ogre_1_1_composition_pass.html#a88bc728d5e0497ce4c5dbc052239551d", null ],
    [ "setCustomType", "class_ogre_1_1_composition_pass.html#a0937b1f59f584797d44383eeb44b30eb", null ],
    [ "getCustomType", "class_ogre_1_1_composition_pass.html#a3efae9c2f40f1f44a148497797c2f8f0", null ]
];

==> ogre-docs-1.12.1-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/class_ogre_1_1_composition_pass.js <==
var class_ogre_1_1_composition_pass =
[
    [ "InputTex", "struct_ogre_1_1_composition_pass_1_1_input_tex.html", "struct_ogre_1_1_composition_pass_1_1_input_tex" ],
    [ "PassType", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aa", [
      [ "PT_CLEAR", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaaa7d4ed28ab9cdd43e85a715bd4e068fc", null ],
      [ "PT_STENCIL", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaa43301dad285fba17915d7867665597ab", null ],
      [ "PT_RENDERSCENE", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaac8aa60611671e1b8867c1a30775ba84c", null ],
      [ "PT_RENDERQUAD", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaa39b1d2658f5c73b04755e428316ea366", null ],
      [ "PT_RENDERCUSTOM", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaaba93db3e2878858fe2fd199354c82af9", null ],
      [ "PT_COMPUTE", "class_ogre_1_1_composition_pass.html#aa20bff864069127a799a3593df0146aaafa19263d8a14d62c4aec06a1dd14f6ed", null ]
    ] ],
    [ "CompositionPass", "class_ogre_1_1_composition_pass.html#a5b5540cb8dc10175dc30c3947032013c", null ],
    [ "~CompositionPass", "class_ogre_1_1_composition_pass.html#ab8fc137845790b360d57056621cd1061", null ],
    [ "setType", "class_ogre_1_1_composition_pass.html#a8b0e3dcfccbdcc9672a96ae6dc2c0123", null ],
    [ "getType", "class_ogre_1_1_composition_pass.html#a6a51eff0938089a5fc26c1bec5c3778f", null ],
    [ "setIdentifier", "class_ogre_1_1_composition_pass.html#a56bb1d899a43195712944398e2d1bc65", null ],
    [ "getIdentifier", "class_ogre_1_1_composition_pass.html#ab60bfaaed2a48057ac8e8e7ead113f60", null ],
    [ "setMaterial", "class_ogre_1_1_composition_pass.html#a21721f49c3b10e36560adff1e563740f", null ],
    [ "setMaterialName", "class_ogre_1_1_composition_pass.html#a453231b980fc04dd9af9f330feec5236", null ],
    [ "getMaterial", "class_ogre_1_1_composition_pass.html#a0367e89580ffd67000ce52676866fa43", null ],
    [ "setFirstRenderQueue", "class_ogre_1_1_composition_pass.html#a4af9e5a958c5ec3a69f8bd797d4c2563", null ],
    [ "getFirstRenderQueue", "class_ogre_1_1_composition_pass.html#ab7f667605829412a22d0cccd9c1d7e6c", null ],
    [ "setLastRenderQueue", "class_ogre_1_1_composition_pass.html#a193d54ee08e19d538576ca300c30c006", null ],
    [ "getLastRenderQueue", "class_ogre_1_1_composition_pass.html#a1947a2e49e4c78d3fa806933690e6522", null ],
    [ "setMaterialScheme", "class_ogre_1_1_composition_pass.html#afdc03ddab7dba7ca065345a0ab5351fd", null ],
    [ "getMaterialScheme", "class_ogre_1_1_composition_pass.html#a822bb35bad3ba41e1370c08891428053", null ],
    [ "setClearBuffers", "class_ogre_1_1_composition_pass.html#a92187a460af36b8ebe0828cf6d81c277", null ],
    [ "getClearBuffers", "class_ogre_1_1_composition_pass.html#a86b647f3dff3e2fc021302c23827b603", null ],
    [ "setClearColour", "class_ogre_1_1_composition_pass.html#a749020e95d4cd6d908983d042b86e429", null ],
    [ "getClearColour", "class_ogre_1_1_composition_pass.html#a548f5811f1b762b2a64257367f564378", null ],
    [ "setAutomaticColour", "class_ogre_1_1_composition_pass.html#ad72002d4220edc51b6ac40bbd811cbee", null ],
    [ "getAutomaticColour", "class_ogre_1_1_composition_pass.html#ac4fae76a4f67e1ea70dc270be9b0daed", null ],
    [ "setClearDepth", "class_ogre_1_1_composition_pass.html#a1f0e9945281c6551ab0f21a129270339", null ],
    [ "getClearDepth", "class_ogre_1_1_composition_pass.html#a3c873101dd6bb94c9cea93fcc2a6e55b", null ],
    [ "setClearStencil", "class_ogre_1_1_composition_pass.html#ad75218db6dbe9993b5486c9c916efc0c", null ],
    [ "getClearStencil", "class_ogre_1_1_composition_pass.html#adfa90e05d769083fe4823a6fff4177c0", null ],
    [ "setStencilCheck", "class_ogre_1_1_composition_pass.html#af0f6a55176e7c69fda820a5d22a50104", null ],
    [ "getStencilCheck", "class_ogre_1_1_composition_pass.html#a31e5b47326f6357b7172faca282cb3ea", null ],
    [ "setStencilFunc", "class_ogre_1_1_composition_pass.html#a7d60b3d8f6e47891d8e5373bea31d5bd", null ],
    [ "getStencilFunc", "class_ogre_1_1_composition_pass.html#a14fcb5fbfd45871dca725c88de5a83a5", null ],
    [ "setStencilRefValue", "class_ogre_1_1_composition_pass.html#a1b8cc0c3221bfbc751328cda98c8aff7", null ],
    [ "getStencilRefValue", "class_ogre_1_1_composition_pass.html#a2fd6b67d996e8a9c9a7b8443490e997e", null ],
    [ "setStencilMask", "class_ogre_1_1_composition_pass.html#a052e16876215e11e03bcba8657faf917", null ],
    [ "getStencilMask", "class_ogre_1_1_composition_pass.html#af347ecd30bdb07219cb1794599b30ec7", null ],
    [ "setStencilFailOp", "class_ogre_1_1_composition_pass.html#ad7afd96369d5093b5eb2123f2befed58", null ],
    [ "getStencilFailOp", "class_ogre_1_1_composition_pass.html#a354620f0bec90c923b57707019195483", null ],
    [ "setStencilDepthFailOp", "class_ogre_1_1_composition_pass.html#ae3c196d705b7bf120e0d888b4867dda4", null ],
    [ "getStencilDepthFailOp", "class_ogre_1_1_composition_pass.html#adcd852af123434d7ff154a2569121d27", null ],
    [ "setStencilPassOp", "class_ogre_1_1_composition_pass.html#aff4417885952905fc8230cef47a36756", null ],
    [ "getStencilPassOp", "class_ogre_1_1_composition_pass.html#a6e14a28e603b902ee0794f78912f329f", null ],
    [ "setStencilTwoSidedOperation", "class_ogre_1_1_composition_pass.html#afa3d6c2f5f8e6ba85b7844d2bf433a5f", null ],
    [ "getStencilTwoSidedOperation", "class_ogre_1_1_composition_pass.html#a45657514c52a86f22d9d575fa248de0a", null ],
    [ "setStencilReadBackAsTextureOperation", "class_ogre_1_1_composition_pass.html#a4eb731c1f04905fee30f0317815963f6", null ],
    [ "getStencilReadBackAsTextureOperation", "class_ogre_1_1_composition_pass.html#ad3b550fd01154eddeaf8cbc7459c75f9", null ],
    [ "setInput", "class_ogre_1_1_composition_pass.html#afa546e1e7d46879c3dc6ce5dff470d4d", null ],
    [ "getInput", "class_ogre_1_1_composition_pass.html#ae5884df0782f751715d36c0027912760", null ],
    [ "getNumInputs", "class_ogre_1_1_composition_pass.html#a88aed71c3c005bea6be70c8d58db3232", null ],
    [ "clearAllInputs", "class_ogre_1_1_composition_pass.html#a05cbca68fbc408dbf755612cfb72707d", null ],
    [ "getParent", "class_ogre_1_1_composition_pass.html#a5815c0e9e598fe58d2c7f76be9167976", null ],
    [ "_isSupported", "class_ogre_1_1_composition_pass.html#ac0daef1d307ace963959896a3db64d75", null ],
    [ "setQuadCorners", "class_ogre_1_1_composition_pass.html#a58915b98148aef94f7bc887983db41d3", null ],
    [ "setQuadCorners", "class_ogre_1_1_composition_pass.html#a186b5a3bcb90a3ce1d66f97424cd339c", null ],
    [ "getQuadCorners", "class_ogre_1_1_composition_pass.html#ab80f5bdd57e0c746293bdd5a9f3adef2", null ],
    [ "getQuadCorners", "class_ogre_1_1_composition_pass.html#a0a8e642c52e2b7db79765f93b1cf5730", null ],
    [ "setQuadFarCorners", "class_ogre_1_1_composition_pass.html#ac2831cd42c94887f6e239d1460dc6b5c", null ],
    [ "getQuadFarCorners", "class_ogre_1_1_composition_pass.html#ae350fcee79e006e23d6de413253568e5", null ],
    [ "getQuadFarCornersViewSpace", "class_ogre_1_1_composition_pass.html#a88bc728d5e0497ce4c5dbc052239551d", null ],
    [ "setCustomType", "class_ogre_1_1_composition_pass.html#a0937b1f59f584797d44383eeb44b30eb", null ],
    [ "getCustomType", "class_ogre_1_1_composition_pass.html#a3efae9c2f40f1f44a148497797c2f8f0", null ],
    [ "setThreadGroups", "class_ogre_1_1_composition_pass.html#a59249a96733d39ab3df8b073ef9d5633", null ],
    [ "getThreadGroups", "class_ogre_1_1_composition_pass.html#aae07036bc113572b68bd3ad85aad4ad0", null ]
];
